/*
* Rebuild Corona Displacement in IR (Corona(legacy)Mtl + CoronaDisplacementMod + CoronaPhysicalMtl)
* 2022 by Frood
*
* Triggering a Corona IR displacement rebuild by switching the state of displacement to its current state.
* Corona 7+ required.
* 
* v0.4
*
* v04: Now trying to start docked IR session first and launch VFB IR as fallback
* v03: Added CoronaDisplacementMod support, added option to start IR if not running
* v02: Added query box if displacement is disabled in render settings.
*
* Todo: Check if it's feasible to support displacement in xref scenes.
* Check if anim off context is needed.
*
* Apparent return codes of startInteractiveDocked() (undocumented)
* 3: No docked IR
* 0: Ok, started
* 2: Already running

*/

macroScript RebuildCoronaIRDisplacement
	category:"Rakete"
	toolTip:"Rebuild Corona IR displacement"
	icon:#("Trackviewstatus",7)

(
	on isenabled do (
		classof renderers.current==CoronaRenderer
	)
	
	on execute do (
		if  ( not (CoronaRenderer.CoronaFP.getRenderType()==3 or CoronaRenderer.CoronaFP.getRenderType()==2)) then (
			if queryBox "Corna IR not running. Start it now?" then (
				if not renderDisplacements then (
					if queryBox ("Displacement is currently disabled. Enable?") title:"Update Corona IR Displacement" then (
						renderDisplacements=true
					)
				)
				if (CoronaRenderer.CoronaFp.startInteractiveDocked()!=0) then (
					CoronaRenderer.CoronaFp.startInteractive()
				)
			)
			else ok
		)
		else (
			if not renderDisplacements then (
				if queryBox ("Displacement is currently disabled. Enable? \nScene will be reparsed.") title:"Update Corona IR Displacement" then (
					renderDisplacements=true
				)
				else ok
			)
		)
		
		if (CoronaMtl!=undefined) then (
			for mat in getClassInstances CoronaMtl			where ((mat.texmapOnDisplacement==true) and (mat.texmapDisplace		!=undefined)) do mat.texmapOnDisplacement=mat.texmapOnDisplacement
		)
		if (CoronaPhysicalMtl!=undefined) then (
			for mat in getClassInstances CoronaPhysicalMtl 	where ((mat.displacementTexmapOn==true) and (mat.displacementTexmap	!=undefined)) do mat.displacementTexmapOn=mat.displacementTexmapOn
		)
		for o in $objects where not o.isHiddenInVpt do (
			for m in o.modifiers where (classof m == CoronaDisplacementMod and m.enabled==true and m.mapSource!=0) do (
				m.enabled=m.enabled
			)
		)
	)
)

